==> mongodb-6.0.25.gh.tar.gz: mongo-r6.0.25/src/mongo/db/query/optimizer/explain_interface.h <==
/**
 *    Copyright (C) 2022-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/bson/bsonobj.h"


namespace mongo::optimizer {

/**
 * Used to abstract away the explaining of the optimizer.
 * Note: we should not depend on anything here (certainly not the rest of the optimizer).
 */
class AbstractABTPrinter {
public:
    virtual ~AbstractABTPrinter() = default;

    virtual BSONObj explainBSON() const = 0;
};

};  // namespace mongo::optimizer

==> mongodb-8.0.12.gh.tar.gz: mongo-r8.0.12/src/mongo/db/query/optimizer/explain_interface.h <==
/**
 *    Copyright (C) 2022-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/bson/bsonobj.h"


namespace mongo::optimizer {

/**
 * Used to abstract away the explaining of the optimizer.
 * Note: we should not depend on anything here (certainly not the rest of the optimizer).
 */
class AbstractABTPrinter {
public:
    virtual ~AbstractABTPrinter() = default;
    virtual BSONObj explainBSON() const = 0;
    virtual BSONObj explainQueryPlannerDebug() const = 0;
    virtual std::string getPlanSummary() const = 0;
    virtual BSONObj getQueryParameters() const = 0;
};

};  // namespace mongo::optimizer
